%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%  Section C: Discrete-time calculation of A and B from R and P.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function Sec_C = bg_Sec_C(Sec_B)
    global  G_PROG ;      
    global  G_FID       ;
    G_FID = fopen(sprintf('test/Sec_C.log',G_PROG), 'w');
    if G_FID
        fprintf(G_FID,'Octave program "%s.m" using "bg_Sec_C.m":\n',G_PROG);
        % Use simplified notation
        fprintf(G_FID,'-------------------------------------------------------\n');
        fprintf(G_FID,'Discrete-time calculation of A and B from R and P.     \n');
        fprintf(G_FID,'Here we use capital letters to indicate variables      \n');
        fprintf(G_FID,'which are transformed similar to those in residuez.m.  \n');
        fprintf(G_FID,'For example, A=conj(fliplr(a)). Also, we do not employ \n');
        fprintf(G_FID,'directly residue.m or residuez.m. The results given    \n');
        fprintf(G_FID,'in "test/Sec_C.log" are identical to those obtained    \n');
        fprintf(G_FID,'using Matlab and C++.                                  \n');
        fprintf(G_FID,'-------------------------------------------------------\n');
        %%  Section B inputs:
        r = Sec_B.r ;
        p = Sec_B.p ;
        k = Sec_B.k ;
        e = Sec_B.e ;
        fprintf(G_FID,'Inputs r, p, k and e:\n');
        bg_print('p',p);
        bg_print('r',r);
        bg_print('k',k);
        bg_print('e',e);
        %%  Convert r and p to R and P
        R1=-r(1)/p(1)   ;
        R2=-r(2)/p(2)   ;
        R3=-r(3)/p(3)   ;
        R4= r(4)/p(4)   ;
        R =[R1;R2;R3;R4]; 
        P1=1/p(1)       ;     
        P2=1/p(2)       ;     
        P3=1            ;     
        P4=1            ;
        P =[P1;P2;P3;P4];
        K=[];
        E=[1;1;1;2];
        fprintf(G_FID,'R, P, K, E are calculated from the above:\n');
        bg_print('P',P);
        bg_print('R',R);
        bg_print('K',K);
        bg_print('E',E);
        fprintf(G_FID,'The discrete-time matrix M is:\n');
%%	M=[	  1	 ,    1       ,     1	       ,    1	     ;
%%		-(2+P2)  ,  -(2+P1)   ,   -(1+P2+P1)   ,  -(P2+P1)   ;
%%	       +(1+2*P2) , +(1+2*P1)  ,  (P2*P1+P2+P1) ,   +P2*P1    ;
%%		 -P2	 ,    -P1     ,   -P2*P1       ,    0	    ];
        M=[       1      ,    1       ,     1          ,    0        ;
                -(2+P2)  ,  -(2+P1)   ,   -(1+P2+P1)   ,    1        ;
               +(1+2*P2) , +(1+2*P1)  ,  (P2*P1+P2+P1) ,  -(P2+P1)   ;
                 -P2     ,    -P1     ,   -P2*P1       ,   +P2*P1   ];
        bg_print('M',M);
        fprintf(G_FID,'Outputs A and B are calculated as:\n');
        B  = [M*R/P1/P2]';
        A1 =  1.00             ; 
        A2 =  -(2+P2+P1)       ; 
        A3 =  1+2*(P2+P1)+P2*P1; 
        A4 = -(P2+P1 +2*P2*P1) ;
        A5 =   P2*P1           ;
        A  = [A1,A2,A3,A4,A5];
        bg_print('A',A);
        bg_print('B',B);
        %Store Section C results
        Sec_C.R=R;
        Sec_C.P=P;
        Sec_C.K=K;
        Sec_C.E=E;
        Sec_C.A=A;
        Sec_C.B=B;
        fprintf(G_FID,'\nConversion of A and B to a and b ');
        fprintf(G_FID,'and comparison with results from Section_B:\n');
        Sec_C.a=fliplr(A)/A(5);
        Sec_C.b=fliplr(B);
        bg_print('Sec_B.a',Sec_B.a);
        bg_print('Sec_C.a',Sec_C.a);
        bg_print('Sec_B.b',Sec_B.b);
        bg_print('Sec_C.b',Sec_C.b);
        fprintf(G_FID,'End of comparison\n');
        fclose(G_FID);
    endif
endfunction
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
